@@ -20,6 +20,7 @@ import uuid
 
 from cdpcli import credentials, DEFAULT_PROFILE_NAME
 from cdpcli import xform_name
+from cdpcli.auth import AccessTokenAuth
 from cdpcli.auth import Ed25519v1Auth
 from cdpcli.auth import RSAv1Auth
 from cdpcli.cdprequest import prepare_request_dict
@@ -58,14 +59,14 @@ class ClientCreator(object):
 
     def create_client(self,
                       service_name,
-                      endpoint_url,
+                      explicit_endpoint_url,
                       tls_verification,
                       credentials,
                       client_config=None):
         service_model = self._load_service_model(service_name)
         cls = self._create_client_class(service_name, service_model)
         client_args = self._get_client_args(service_model,
-                                            endpoint_url,
+                                            explicit_endpoint_url,
                                             tls_verification,
                                             credentials,
                                             client_config)
@@ -86,10 +87,12 @@ class ClientCreator(object):
 
     def _get_client_args(self,
                          service_model,
-                         endpoint_url,
+                         explicit_endpoint_url,
                          tls_verification,
                          credentials,
                          client_config):
+        """Get keyword arguments for constructing a client object.
+        """
         serializer = create_serializer()
         if client_config is not None:
             connect_timeout = client_config.connect_timeout
@@ -103,13 +106,15 @@ class ClientCreator(object):
             read_timeout = DEFAULT_TIMEOUT
         endpoint = self._endpoint_creator.create_endpoint(
             service_model,
-            endpoint_url,
+            explicit_endpoint_url,
             self._context.get_scoped_config(),
             self._response_parser_factory,
             tls_verification,
             (connect_timeout, read_timeout),
             self._retryhandler)
-        if Ed25519v1Auth.detect_private_key(credentials.private_key):
+        if AccessTokenAuth.is_access_token(credentials.access_token):
+            auth_method = AccessTokenAuth.AUTH_METHOD_NAME
+        elif Ed25519v1Auth.detect_private_key(credentials.private_key):
             auth_method = Ed25519v1Auth.AUTH_METHOD_NAME
         else:
             auth_method = RSAv1Auth.AUTH_METHOD_NAME
@@ -290,6 +295,9 @@ class Context(object):
         # This is the shared credentials file.
         'credentials_file': (None, 'CDP_SHARED_CREDENTIALS_FILE',
                              '~/.cdp/credentials', None),
+        'cdp_endpoint_url': ('cdp_endpoint_url', None, None, None),
+        'endpoint_url': ('endpoint_url', None, None, None),
+        'form_factor': ('form_factor', None, None, None),
     }
 
     def __init__(self, profile=None):
@@ -489,7 +497,7 @@ class Context(object):
         """
         self._context_instance_vars[logical_name] = value
 
-    def get_credentials(self):
+    def get_credentials(self, parsed_globals=None):
         """
         Return the :class:`botocore.credential.Credential` object
         associated with this session.  If the credentials have not
@@ -499,5 +507,6 @@ class Context(object):
 
         """
         if self._credentials is None:
-            resolver = credentials.create_credential_resolver(self)
-            return resolver.load_credentials()
+            resolver = credentials.create_credential_resolver(self, parsed_globals)
+            self._credentials = resolver.load_credentials()
+        return self._credentials
